<template>
    <div class="map-target">
        <div class="map-tip-container">
            <div class="map-container" :element-loading-background="loadingColor" v-loading="loading">
                <div :id="CQId"></div>
                <div :id="main9Id">
                    <div :class="['ljxq', `grade-${ljxqGrade}`]" @click="goToSub('ljxq')">
                        <i class="dot"></i>
                    </div>
                    <div :class="['gxq', `grade-${gxqGrade}`]" @click="goToSub('gxq')">
                        <i class="dot"></i>
                    </div>
                </div>
            </div>
            <div class="fdgz">
                不涉及区县：渝中区
            </div>
            <div class="map-tip">
                <div class="tip-item">
                    <div class="level-title">A档</div>
                    <div class="tip-text">
                        ≥全市水平值({{ meanObj.yqkfqSpz }} %)等分为两档,第1档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">B档</div>
                    <div class="tip-text">
                        ≥全市水平值({{ meanObj.yqkfqSpz }} %)等分为两档,第2档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">C档</div>
                    <div class="tip-text">
                        ＜全市水平值({{ meanObj.yqkfqSpz }} %)等分为两档,第1档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">D档</div>
                    <div class="tip-text">
                        ＜全市水平值({{ meanObj.yqkfqSpz }} %)等分为两档,第2档
                    </div>
                </div>
                <!-- 五档：A档（第1—9位）、B档（第10—17位）、C档（第18—25位）、D档（第26—33位）、E档（第34—41位），分别对应绿、蓝、黄、橙、红“五色图”。 -->
            </div>
        </div>

        <div class="list-container">
            <air-table @loadComplete="loadComplete" :data="tableData" :tableColumn="tableColumn" :lsFd="lsFd"></air-table>
        </div>
    </div>
</template>

<script>
import airTable from './airTable.vue'
import mapTargetMixin from '@/mixins/mapTargetMixin.js'
export default {
    mixins: [mapTargetMixin],
    components: {
        airTable,
    },
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
        CQId: {
            type: String,
            default: 'cq-contianer_15',
        },
        main9Id: {
            type: String,
            default: 'main9-contianer_15',
        },
        isClick: {
            type: Boolean,
            default: true,
        },
    },
    data() {
        return {
            tableColumn: [
                { label: '排名', prop: 'yqkfqSn' },
                { label: '区县', prop: 'unitName' },
                { label: '实际值(%)', prop: 'yqkfqSjz' },
                { label: '得分', prop: 'yqkfqScore' },
            ],
            typeNum: 'yqkfqSjz',
            typeGrade: 'yqkfqGrade',
            isFirm: false,
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        // this.setTableColumn()
        this.initData()
        this.$bus.$on('changeDate', () => {
            this.setLsFd()
            // this.setTableColumn()
            this.initData()
        })
        this.$nextTick(() => {
            this.initMapMain()
            this.initMapCQ()
        })
        this.$root.$on('resize', () => {
            this.resize(500)
        })
        this.setLsFd()
    },
    methods: {
        setTableColumn() {
            let { year, quarter } = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            if (year === 2023 && quarter < 4 && quarter !== 0) {
                this.tableColumn = [
                    { label: '排名', prop: 'yqkfqSn' },
                    { label: '区县', prop: 'unitName' },
                    { label: '实际值(%)', prop: 'yqkfqRate' }
                ]
            } else {
                this.tableColumn = [
                    { label: '排名', prop: 'yqkfqSn' },
                    { label: '区县', prop: 'unitName' },
                    { label: '实际值(%)', prop: 'yqkfqRate' },
                    { label: '得分', prop: 'yqkfqScore' },
                ]
            }
        },
    }
}
</script>

<style lang="scss" scoped>
@import './target.scss';

.map-tip {
    bottom: 0;
}

.map-target {
    padding: 30PX 35PX;
}

.level-container {
    display: flex;
    flex-direction: column;
    height: 100%;
    // height: 765px;
    flex-wrap: wrap;
    row-gap: 0;
    align-content: flex-end;

    >* {
        width: 30.33%;
        // flex: 1;
        font-family: '微软雅黑', sans-serif !important;
    }

    .level-title {
        display: flex;
        align-items: center;
        justify-content: center;
        text-align: center;
        font-size: 24PX;
        font-weight: bold;
        // height: calc(100% / 17);
        height: 32PX;
        line-height: 32PX;
        margin-top: 20PX;

        &:last-child {
            margin-bottom: 5px;
        }
    }

    .level-title-A {
        margin-top: 0;
        background-color: #398C8F;
    }

    .level-title-B {
        background-color: #1970c1;
    }

    .level-title-C {
        background-color: #A3A355;
    }

    .level-title-D {
        background-color: #B0825C;
    }

    .level-title-E {
        background-color: #9B4E55;
    }

    .level-header,
    .level-content-item {
        align-items: center;
        // line-height: 30px;
        margin: 0;
        height: calc(100% / 18);

        span {
            text-align: center;
            font-size: 18px;
            // display: inline-block;
            // padding: 12px 2px;
            flex: 1;
            text-align: center;
            // color:#b1e3ff;

            &:first-child {
                flex: 1.3;
            }

            &:last-child {
                flex: 1;
            }
        }

    }
}
</style>
